@@ -15,6 +15,7 @@ use Locale::Maketext::Extract;
 use App::I18N::Logger;
 use Cwd;
 use Encode;
+use File::Spec;
 use MIME::Types ();
 use constant USE_GETTEXT_STYLE => 1;
 
@@ -148,7 +149,7 @@ to msgstr (zh\_TW):
 
 # our @EXPORT = qw(_);
 
-our $VERSION = 0.013;
+our $VERSION = 0.03;
 our $LOGGER;
 our $LMExtract;
 our $MIME = MIME::Types->new();
@@ -199,7 +200,7 @@ sub _check_mime_type {
 
 sub extract_messages {
     my ( $self, @dirs ) = @_;
-    my @files  = File::Find::Rule->file->in(@dirs);
+    my @files = map { ( -d $_ ) ? File::Find::Rule->file->in($_) : $_ } @dirs;
     my $logger = $self->logger;
     my $lme = $self->lm_extract;
     foreach my $file (@files) {
@@ -207,9 +208,7 @@ sub extract_messages {
         next if $file =~ m{\~$};
         next if $file =~ m{\.pod$};
         next if $file =~ m{^\.git};
-
         next unless $self->_check_mime_type($file);
-
         $logger->info("Extracting messages from '$file'");
         $lme->extract_file($file);
     }
@@ -263,6 +262,18 @@ sub guess_podir {
     return $podir;
 }
 
+sub get_po_path {
+    my ( $self, $podir, $lang, $is_locale ) = @_;
+    my $pot_name = App::I18N->pot_name;
+    my $path;
+    if ($is_locale) {
+        $path = File::Spec->join( $podir, $lang . ".po" );
+    }
+    else {
+        $path = File::Spec->join( $podir, 'locale', $lang, 'LC_MESSAGES', $pot_name . ".po" );
+    }
+    return $path;
+}
 
 sub update_catalogs {
     my ($self,$podir , $cmd ) = @_;
@@ -284,4 +295,8 @@ sub update_catalogs {
 }
 
 
+
+# _('Internationalization')
+# _('Translate me')
+
 1;
